@@ -8,25 +8,23 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KONTACT_MAINWINDOW_H
-#define KONTACT_MAINWINDOW_H
+#pragma once
 
 #include "kontact_export.h"
 #include <KontactInterface/Core>
 #include <KontactInterface/Plugin>
-#include <QAction>
 
 class KActionMenu;
 class KPluginInfo;
 class KSqueezedTextLabel;
-
+class QAction;
 class QFrame;
 class QSplitter;
 class QStackedWidget;
 class IntroductionWebEngineView;
 
-typedef QList<KontactInterface::Plugin *> PluginList;
-typedef QList<QAction *> ActionPluginList;
+using PluginList = QList<KontactInterface::Plugin *>;
+using ActionPluginList = QList<QAction *>;
 
 namespace Kontact
 {
@@ -137,4 +135,3 @@ private:
 
 Q_DECLARE_METATYPE(KontactInterface::Plugin *)
 
-#endif
